@@ -1,5 +1,5 @@
 """
-Render to qt from agg
+Render to qt from agg.
 """
 
 import ctypes
@@ -21,7 +21,8 @@ class FigureCanvasQTAgg(FigureCanvasAgg, FigureCanvasQT):
         super().__init__(figure=figure)
 
     def paintEvent(self, event):
-        """Copy the image from the Agg canvas to the qt.drawable.
+        """
+        Copy the image from the Agg canvas to the qt.drawable.
 
         In Qt, all drawing should be done inside of here when a widget is
         shown onscreen.
@@ -31,37 +32,43 @@ class FigureCanvasQTAgg(FigureCanvasAgg, FigureCanvasQT):
             return
         self._draw_idle()  # Only does something if a draw is pending.
 
-        # if the canvas does not have a renderer, then give up and wait for
-        # FigureCanvasAgg.draw(self) to be called
+        # If the canvas does not have a renderer, then give up and wait for
+        # FigureCanvasAgg.draw(self) to be called.
         if not hasattr(self, 'renderer'):
             return
 
         painter = QtGui.QPainter(self)
 
-        if self._erase_before_paint:
-            painter.eraseRect(self.rect())
-            self._erase_before_paint = False
-
-        rect = event.rect()
-        left = rect.left()
-        top = rect.top()
-        width = rect.width()
-        height = rect.height()
         # See documentation of QRect: bottom() and right() are off by 1, so use
         # left() + width() and top() + height().
-        bbox = Bbox(
-            [[left, self.renderer.height - (top + height * self._dpi_ratio)],
-             [left + width * self._dpi_ratio, self.renderer.height - top]])
+        rect = event.rect()
+        # scale rect dimensions using the screen dpi ratio to get
+        # correct values for the Figure coordinates (rather than QT5's coords)
+        width = rect.width() * self._dpi_ratio
+        height = rect.height() * self._dpi_ratio
+        left, top = self.mouseEventCoords(rect.topLeft())
+        # shift the "top" by the height of the image to get the
+        # correct corner for our coordinate system
+        bottom = top - height
+        # same with the right side of the image
+        right = left + width
+        # create a buffer using the image bounding box
+        bbox = Bbox([[left, bottom], [right, top]])
         reg = self.copy_from_bbox(bbox)
         buf = cbook._unmultiplied_rgba8888_to_premultiplied_argb32(
             memoryview(reg))
+
+        # clear the widget canvas
+        painter.eraseRect(rect)
+
         qimage = QtGui.QImage(buf, buf.shape[1], buf.shape[0],
                               QtGui.QImage.Format_ARGB32_Premultiplied)
         if hasattr(qimage, 'setDevicePixelRatio'):
             # Not available on Qt4 or some older Qt5.
             qimage.setDevicePixelRatio(self._dpi_ratio)
-        origin = QtCore.QPoint(left, top)
-        painter.drawImage(origin / self._dpi_ratio, qimage)
+        # set origin using original QT coordinates
+        origin = QtCore.QPoint(rect.left(), rect.top())
+        painter.drawImage(origin, qimage)
         # Adjust the buf reference count to work around a memory
         # leak bug in QImage under PySide on Python 3.
         if QT_API in ('PySide', 'PySide2'):
@@ -72,8 +79,7 @@ class FigureCanvasQTAgg(FigureCanvasAgg, FigureCanvasQT):
         painter.end()
 
     def blit(self, bbox=None):
-        """Blit the region in bbox.
-        """
+        # docstring inherited
         # If bbox is None, blit the entire canvas. Otherwise
         # blit only the area defined by the bbox.
         if bbox is None and self.figure:
