@@ -46,18 +46,21 @@ generate entries for the resulting legend - it is worth noting however that
 not all artists can be added to a legend, at which point a "proxy" will have
 to be created (see :ref:`proxy_legend_handles` for further details).
 
+Those artists with an empty string as label or with a label starting with
+"_" will be ignored.
+
 For full control of what is being added to the legend, it is common to pass
 the appropriate handles directly to :func:`legend`::
 
-    line_up, = plt.plot([1,2,3], label='Line 2')
-    line_down, = plt.plot([3,2,1], label='Line 1')
+    line_up, = plt.plot([1, 2, 3], label='Line 2')
+    line_down, = plt.plot([3, 2, 1], label='Line 1')
     plt.legend(handles=[line_up, line_down])
 
 In some cases, it is not possible to set the label of the handle, so it is
 possible to pass through the list of labels to :func:`legend`::
 
-    line_up, = plt.plot([1,2,3], label='Line 2')
-    line_down, = plt.plot([3,2,1], label='Line 1')
+    line_up, = plt.plot([1, 2, 3], label='Line 2')
+    line_down, = plt.plot([3, 2, 1], label='Line 1')
     plt.legend([line_up, line_down], ['Line Up', 'Line Down'])
 
 
@@ -117,14 +120,14 @@ plt.plot([3, 2, 1], label="test2")
 
 # Place a legend above this subplot, expanding itself to
 # fully use the given bounding box.
-plt.legend(bbox_to_anchor=(0., 1.02, 1., .102), loc=3,
+plt.legend(bbox_to_anchor=(0., 1.02, 1., .102), loc='lower left',
            ncol=2, mode="expand", borderaxespad=0.)
 
 plt.subplot(223)
 plt.plot([1, 2, 3], label="test1")
 plt.plot([3, 2, 1], label="test2")
 # Place a legend to the right of this smaller subplot.
-plt.legend(bbox_to_anchor=(1.05, 1), loc=2, borderaxespad=0.)
+plt.legend(bbox_to_anchor=(1.05, 1), loc='upper left', borderaxespad=0.)
 
 plt.show()
 
@@ -144,13 +147,13 @@ line1, = plt.plot([1, 2, 3], label="Line 1", linestyle='--')
 line2, = plt.plot([3, 2, 1], label="Line 2", linewidth=4)
 
 # Create a legend for the first line.
-first_legend = plt.legend(handles=[line1], loc=1)
+first_legend = plt.legend(handles=[line1], loc='upper right')
 
 # Add the legend manually to the current Axes.
 ax = plt.gca().add_artist(first_legend)
 
 # Create another legend for the second line.
-plt.legend(handles=[line2], loc=4)
+plt.legend(handles=[line2], loc='lower right')
 
 plt.show()
 
@@ -237,11 +240,11 @@ l = plt.legend([(p1, p2)], ['Two keys'], numpoints=1,
 import matplotlib.patches as mpatches
 
 
-class AnyObject(object):
+class AnyObject:
     pass
 
 
-class AnyObjectHandler(object):
+class AnyObjectHandler:
     def legend_artist(self, legend, orig_handle, fontsize, handlebox):
         x0, y0 = handlebox.xdescent, handlebox.ydescent
         width, height = handlebox.width, handlebox.height
